Address
  {$ ::ctrl.member.address $}
Protocol Port
  {$ ::ctrl.member.protocol_port $}
Weight
  {$ ctrl.member.weight $}
Operating Status
  {$ ctrl.member.operating_status | decode:ctrl.operatingStatus $}
Provisioning Status
  {$ ctrl.member.provisioning_status | decode:ctrl.provisioningStatus $}
Admin State Up
  {$ ctrl.member.admin_state_up | yesno $}
Member ID
  {$ ::ctrl.member.id $}
Tenant ID
  {$ ::ctrl.member.tenant_id $}